==> haskell-persistent-mysql-2.13.1.3-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-mysql
version:              2.13.1.3
visibility:           public
id:                   persistent-mysql-2.13.1.3-4vxMgTlp3jmINP33asZSOf
key:                  persistent-mysql-2.13.1.3-4vxMgTlp3jmINP33asZSOf
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  93993fb0e430d054a6e5f1753b74d422
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-mysql-2.13.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-mysql-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.3-4vxMgTlp3jmINP33asZSOf
depends:
    aeson-2.1.2.1-5xA96pEAe1OF80YjsNpBtK base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    conduit-1.3.6-4nxUBFRe7qx8JsNUl8azVI containers-0.6.5.1
    monad-logger-0.3.40-4kkTZO9t3AO5GK8fipue5K
    mysql-0.2.1-EkGveZYOPt6Am2dCuw4r7Z
    mysql-simple-0.4.9-KrMgOfBSLlkB8e0a3poKrl
    persistent-2.14.5.1-8jJvVZnkQDZ2uluYgRJ347
    resource-pool-0.2.3.2-6eKe81sHrMwIqALAn8hUru
    resourcet-1.2.6-CWtJGH6acq3JRI3WPjesPj text-1.2.5.0
    transformers-0.5.6.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-mysql-2.13.1.3-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-mysql
version:              2.13.1.3
visibility:           public
id:                   persistent-mysql-2.13.1.3-IyJVnHN2KI0AgBolk06Qe7
key:                  persistent-mysql-2.13.1.3-IyJVnHN2KI0AgBolk06Qe7
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  114961d149dd038019a52097d3ff3f3c
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-mysql-2.13.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-mysql-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.3-IyJVnHN2KI0AgBolk06Qe7
depends:
    aeson-2.1.2.1-IkP1OjeNuTxglWxWeIvI9 base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    conduit-1.3.6-FMkxkIELY206tJUNMQQAmY containers-0.6.5.1
    monad-logger-0.3.40-7xHzLnZODzTIvV2hbLJkZE
    mysql-0.2.1-8CKN4GQc36WKofHgpIOhuU
    mysql-simple-0.4.9-HUoQyTFTL3sImX1vdQMuLm
    persistent-2.14.5.1-5L4chYy1JGVbnkOXl1bLZ
    resource-pool-0.2.3.2-F1zbBy3fCzOEyeaRJJMTGS
    resourcet-1.2.6-Lqb3m6tuOhHIikJo8Ch6Wd text-1.2.5.0
    transformers-0.5.6.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
